@@ -362,7 +362,7 @@ void mpi_bcast_event_slave(int node, int event)
 {
   switch (event) {
 #ifdef ELECTROSTATICS
-#ifdef ELP3M
+#ifdef P3M
   case P3M_COUNT_CHARGES:
     P3M_count_charged_particles();
     break;
@@ -383,13 +383,11 @@ void mpi_bcast_event_slave(int node, int event)
     break;
 #endif
 
-#ifdef MAGNETOSTATICS
-#ifdef ELP3M
+#ifdef DP3M
   case P3M_COUNT_DIPOLES:
     P3M_count_magnetic_particles();
     break;
 #endif
-#endif 
 
   default:;
   }
@@ -1685,7 +1683,7 @@ void mpi_bcast_coulomb_params_slave(int node, int parm)
   switch (coulomb.method) {
   case COULOMB_NONE:
     break;
-#ifdef ELP3M
+#ifdef P3M
   case COULOMB_ELC_P3M:
     MPI_Bcast(&elc_params, sizeof(ELC_struct), MPI_BYTE, 0, MPI_COMM_WORLD);
     // fall through
@@ -1723,7 +1721,7 @@ void mpi_bcast_coulomb_params_slave(int node, int parm)
   switch (coulomb.Dmethod) {
   case DIPOLAR_NONE:
     break;
-#ifdef ELP3M
+#ifdef DP3M
   case DIPOLAR_MDLC_P3M:
     MPI_Bcast(&dlc_params, sizeof(DLC_struct), MPI_BYTE, 0, MPI_COMM_WORLD);
     // fall through
