@@ -1,6 +1,7 @@
 /*
   Copyright (C) 2010 The ESPResSo project
-  Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 Max-Planck-Institute for Polymer Research, Theory Group, PO Box 3148, 55021 Mainz, Germany
+  Copyright (C) 2002,2003,2004,2005,2006,2007,2008,2009,2010 
+    Max-Planck-Institute for Polymer Research, Theory Group
   
   This file is part of ESPResSo.
   
@@ -21,8 +22,8 @@
     Pressure calculation. Really similar to \ref energy.h "energy.h".
 */
 
-#ifndef PRESSURE_H
-#define PRESSURE_H
+#ifndef _PRESSURE_H
+#define _PRESSURE_H
 
 #include "utils.h"
 #include "integrate.h"
@@ -113,7 +114,7 @@ MDINLINE void add_non_bonded_pair_virials(Particle *p1, Particle *p2, double d[3
   /* real space coulomb */
   if (coulomb.method != COULOMB_NONE) {
     switch (coulomb.method) {
-#ifdef ELP3M
+#ifdef P3M
     case COULOMB_P3M:
       ret = p3m_coulomb_pair_energy(p1->p.q*p2->p.q,d,dist2,dist);
       break;
@@ -166,7 +167,7 @@ MDINLINE void add_non_bonded_pair_virials(Particle *p1, Particle *p2, double d[3
   /* real space magnetic dipole-dipole */
   if (coulomb.Dmethod != DIPOLAR_NONE) {
     switch (coulomb.Dmethod) {
-#ifdef ELP3M
+#ifdef DP3M
     case  DIPOLAR_P3M:
         /*ret = p3m_dipolar_pair_energy(p1->p.q*p2->p.q,d,dist2,dist);*/
 	fprintf(stderr,"virials Not working for dipoles P3M .... pressure.h \n");
@@ -521,7 +522,16 @@ MDINLINE void add_kinetic_virials(Particle *p1,int v_comp)
     virials.data.e[0] += (SQR(p1->m.v[0]) + SQR(p1->m.v[1]) + SQR(p1->m.v[2]))*PMASS(*p1);
 
 #ifdef ROTATION
+#ifdef ROTATIONAL_INERTIA
+  /* the rotational part is added to the total kinetic energy;
+     Here we use the rotational inertia  */
+
+  virials.data.e[0] += (SQR(p1->m.omega[0])*p1->p.rinertia[0] +
+		       SQR(p1->m.omega[1])*p1->p.rinertia[1] +
+		       SQR(p1->m.omega[2])*p1->p.rinertia[2])*time_step*time_step;
+#else
   virials.data.e[0] += (SQR(p1->m.omega[0]) + SQR(p1->m.omega[1]) + SQR(p1->m.omega[2]))*SQR(time_step);
+#endif
 #endif
 
   /* ideal gas contribution (the rescaling of the velocities by '/=time_step' each will be done later) */
